"""Test suite for Tag.py"""
# Copyright 2008, Darcy Mason
# This file is part of pydicom.
#
# pydicom is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# pydicom is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License (license.txt) for more details

import unittest
from dicom.tag import Tag

class Values(unittest.TestCase):
    def testGoodInts(self):
        """Tags can be constructed with 4-byte integers.............."""
        tag = Tag(0x300a00b0)
        tag = Tag(0xFFFFFFEE)
    def testGoodTuple(self):
        """Tags can be constructed with two-tuple of 2-byte integers."""
        tag = Tag((0x300a, 0x00b0))
        tag = Tag((0xFFFF, 0xFFee))
    def testBadTuple(self):
        """Tags: if a tuple, must be a 2-tuple......................."""
        self.assertRaises(ValueError, Tag, (1,2,3,4))
    def testNonNumber(self):
        """Tags cannot be instantiated from a string................."""
        self.assertRaises(ValueError, Tag, "hello")
    def testStr(self):
        """Tags have (gggg, eeee) string rep........................."""
        self.assert_(str(Tag(0x300a00b0))=="(300a, 00b0)")
    def testGroup(self):
        """Tags' group and elem portions extracted properly.........."""
        tag = Tag(0x300a00b0)
        self.assert_(tag.group == 0x300a)
        self.assert_(tag.elem == 0xb0)
        self.assert_(tag.element == 0xb0)
        
    def testBadInts(self):
        """Tags constructed with > 8 bytes gives OverflowError......."""
        self.assertRaises(OverflowError, Tag, 0x123456789)

class Comparisons(unittest.TestCase):
    def setUp(self):
        self.int1 = 0x300a00b0
        self.tup1 = (0x300a, 0xb0)
        self.tup3 = (0xFFFE, 0xFFFC)
        self.t1 = Tag(self.int1)
        self.t2 = Tag(self.tup1)
        self.t3 = Tag(self.tup3)
    def testCmp(self):
        """Tags compare correctly (==, <, >)........................."""
        self.assert_(self.t1==self.int1, "tag != int")
        self.assert_(self.t1==self.t2, "tag != other tag")
        self.assert_(self.t1==self.tup1, "tag != tuple")
        self.assert_(self.t1 < self.int1+1, "tag < failed")
        self.assert_(self.int1+1 > self.t1, "int > tag failed")
        self.assert_(self.t3 > self.t1, "'negative' int tag > other tag failed")
    def testHash(self):
        """Tags hash the same as an int.............................."""
        self.assert_(hash(self.t1)==hash(self.int1))
        self.assert_(hash(self.t2)==hash(self.int1))
        
if __name__ == "__main__":
    unittest.main()
